

set -ex



rio --help
rio info /opt/concourse/worker/volumes/live/2fda24a2-4a90-4a41-5bb6-6e3e15391483/volume/rsync-recipes/rasterio-1.1.0-python_3.6-on-osx/test_data/test.tif
$PYTHON -m pytest -v -m "not wheel" -rxXs -k "not (test_transform_geom_polygon_cutting or test_transform_geom_polygon_offset)" tests
exit 0
